/*
   FNT - Stream handler for socket connections
   closing socket

   Copyright (C) 2009 Free Software Foundation, Inc.

   Written by:
   Slava Zanko <slavazanko@gmail.com>


   This file is part of the FIDO New Technology.

   FIDO New Technology is free software: you can redistribute it and/or 
   modify it under the terms of the GNU General Public License as published 
   by the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifdef HAVE_CONFIG_H
#	include <config.h>
#endif

#include <string.h>

#include <sys/types.h>
#include <sys/socket.h>
#include <netinet/in.h>
#include <arpa/inet.h>
#include <errno.h>

#include "../include/global.h"
#include "../include/types.h"
#include "../include/error.h"
#include "../include/stream.h"
#include "../include/mainloop.h"

#include "main.h"
#include "utils.h"

/*** global variables **************************************************/

/*** file scope macro definitions **************************************/

/*** file scope type declarations **************************************/

/*** file scope functions **********************************************/

/*** public functions **************************************************/

DLLEXPORT bool
close_stream (fnt_stream_t * stream)
{
    __fnt_driver_data_t *driver_data;

    if (stream == NULL)
    {
	fnt_error_push (FNT_MODULE_stream, FNT_STREAM_E_OPEN,
			_("Wrong parameters"));
	return false;
    }

    if (stream->driver_data == NULL)
	return false;

    driver_data = (__fnt_driver_data_t *) stream->driver_data;

    g_io_channel_shutdown (driver_data->socket, TRUE, NULL);

    g_free (driver_data->remote_host);
    g_free (driver_data);

    stream->driver_data = NULL;
    return true;
}
